@@ -13,6 +13,7 @@ DccApp *DccApp::instance()
 
 DccApp::DccApp(QObject *parent)
     : QObject(parent)
+    , m_animationMode(AnimationPop)
 {
     Q_ASSERT(!dccApp);
     dccApp = this;
@@ -20,6 +21,14 @@ DccApp::DccApp(QObject *parent)
 
 DccApp::~DccApp() { }
 
+void DccApp::setAnimationMode(AnimationMode mode)
+{
+    if (m_animationMode != mode) {
+        m_animationMode = mode;
+        Q_EMIT animationModeChanged(mode);
+    }
+}
+
 int DccApp::width() const
 {
     return 0;
@@ -40,20 +49,20 @@ DccObject *DccApp::activeObject() const
     return nullptr;
 }
 
-DccObject *DccApp::object(const QString &name)
+DccObject *DccApp::object(const QString &)
 {
     return nullptr;
 }
 
-void DccApp::addObject(DccObject *obj) { }
+void DccApp::addObject(DccObject *) { }
 
-void DccApp::removeObject(DccObject *obj) { }
+void DccApp::removeObject(DccObject *) { }
 
-void DccApp::removeObject(const QString &name) { }
+void DccApp::removeObject(const QString &) { }
 
-void DccApp::showPage(const QString &url) { }
+void DccApp::showPage(const QString &) { }
 
-void DccApp::showPage(DccObject *obj, const QString &cmd) { }
+void DccApp::showPage(DccObject *, const QString &) { }
 
 QWindow *DccApp::mainWindow() const
 {
@@ -70,10 +79,4 @@ QSortFilterProxyModel *DccApp::searchModel() const
     return nullptr;
 }
 
-void DccApp::setShowPath(const QString &path) { }
-
-void DccApp::addSearch(const QString &key, const QString &url) { }
-
-void DccApp::removeSearch(const QString &key) { }
-
 } // namespace dccV25
