@@ -15,6 +15,7 @@
 #include <QRegularExpression>
 #include <QPainterPath>
 #include <QBuffer>
+#include <QTimer>
 
 #include <DSysInfo>
 
@@ -41,6 +42,8 @@ static bool isUserGroupName(int gid, const QString &name)
 AccountsController::AccountsController(QObject *parent)
     : QObject{ parent }
 {
+    qmlRegisterType<CreationResult>("AccountsController", 1, 0, "CreationResult");
+    
     m_model = new UserModel(this);
     m_worker = new AccountsWorker(m_model, this);
 
@@ -54,9 +57,10 @@ AccountsController::AccountsController(QObject *parent)
 
     connect(m_model, &UserModel::avatarChanged, this, &AccountsController::avatarChanged);
     connect(m_model, &UserModel::autoLoginChanged, this, &AccountsController::autoLoginChanged);
+    connect(m_model, &UserModel::quickLoginChanged, this, &AccountsController::quickLoginChanged);
     connect(m_model, &UserModel::nopasswdLoginChanged, this, &AccountsController::nopasswdLoginChanged);
     connect(m_model, &UserModel::groupsChanged, this, [this](const QString &userId, const QStringList &groups) {
-        updateGroups(userId);
+        updateSingleUserGroups(userId);
         Q_EMIT groupsChanged(userId, groups);
     });
     connect(m_model, &UserModel::passwordModifyFinished, this, &AccountsController::passwordModifyFinished);
@@ -66,7 +70,9 @@ AccountsController::AccountsController(QObject *parent)
 
     connect(m_worker, &AccountsWorker::showSafetyPage, this, &AccountsController::showSafetyPage);
     connect(m_model, &UserModel::allGroupsChange, this, [this]() {
-        updateAllGroups();
+        if (!m_isCreatingUser) {
+            updateAllGroups();
+        }
         this->groupsUpdate();
     });
     connect(m_worker, &AccountsWorker::updateGroupFailed, this, &AccountsController::groupsUpdateFailed);
@@ -77,6 +83,19 @@ AccountsController::AccountsController(QObject *parent)
         updateAllGroups();
         this->groupsUpdate();
     });
+    
+    connect(m_worker, &AccountsWorker::accountCreationFinished, this, [this](CreationResult *result) {
+        m_isCreatingUser = false;
+        Q_EMIT accountCreationFinished(result->type(), result->message());
+        
+        if (result->type() == CreationResult::NoError) {
+            QTimer::singleShot(100, this, [this]() {
+                if (!m_model->userList().isEmpty()) {
+                    updateSingleUserGroups(m_model->userList().last()->id());
+                }
+            });
+        }
+    });
 
     QMetaObject::invokeMethod(m_worker, "active", Qt::QueuedConnection);
 }
@@ -222,12 +241,23 @@ bool AccountsController::isAutoLoginVisable() const
     return m_model->isAutoLoginVisable();
 }
 
+bool AccountsController::isQuickLoginVisible() const
+{
+    return m_model->isQuickLoginVisible();
+}
+
 bool AccountsController::autoLogin(const QString &id) const
 {
     User *user = m_model->getUser(id);
     return user ? user->autoLogin() : false;
 }
 
+bool AccountsController::quickLogin(const QString &id) const
+{
+    User *user = m_model->getUser(id);
+    return user ? user->quickLogin() : false;
+}
+
 void AccountsController::setAutoLogin(const QString &id, const bool enable)
 {
     if (User *user = m_model->getUser(id))
@@ -235,6 +265,13 @@ void AccountsController::setAutoLogin(const QString &id, const bool enable)
             m_worker->setAutoLogin(user, enable);
 }
 
+void AccountsController::setQuickLogin(const QString &id, const bool enable)
+{
+    if (User *user = m_model->getUser(id))
+        if (user->quickLogin() != enable)
+            m_worker->setQuickLogin(user, enable);
+}
+
 QString AccountsController::getOtherUserAutoLogin() const
 {
     for (auto user : m_model->userList()) {
@@ -300,12 +337,18 @@ QStringList AccountsController::groups(const QString &id)
 void AccountsController::updateGroups(const QString &id)
 {
     QStringList ag = allGroups();
-    std::sort(ag.begin(), ag.end(), [this, id](const QString &left, const QString &right){
-        bool isLeftContains = groupContains(id, left);
-        bool isRightContains = groupContains(id, right);
+    
+    QHash<QString, bool> containsCache;
+    for (const QString &group : ag) {
+        containsCache[group] = groupContains(id, group);
+    }
+    
+    std::sort(ag.begin(), ag.end(), [&containsCache](const QString &left, const QString &right){
+        bool isLeftContains = containsCache.value(left);
+        bool isRightContains = containsCache.value(right);
 
         if (!(isLeftContains ^ isRightContains)) { // both true or both false
-            return left < right;
+            return left.compare(right, Qt::CaseInsensitive) < 0;
         } else {
             return isLeftContains ? true : false;
         }
@@ -317,17 +360,65 @@ void AccountsController::updateAllGroups()
 {
     if (!m_model)
         return;
-
+    
+    QSet<QString> existingUserIds;
     QList<User *> userList = m_model->userList();
+    
+    QStringList allGroupsList = allGroups();
+    int totalGroups = allGroupsList.size();
+    
     for (const auto user : userList) {
-        updateGroups(user->id());
+        QString id = user->id();
+        existingUserIds.insert(id);
+        
+        QHash<QString, bool> containsCache;
+        for (const QString &group : allGroupsList) {
+            containsCache[group] = groupContains(id, group);
+        }
+        
+        QStringList containedGroups;
+        QStringList notContainedGroups;
+        
+        for (const QString &group : allGroupsList) {
+            if (containsCache.value(group)) {
+                containedGroups.append(group);
+            } else {
+                notContainedGroups.append(group);
+            }
+        }
+        
+        std::sort(containedGroups.begin(), containedGroups.end(), [](const QString &a, const QString &b) {
+            return a.compare(b, Qt::CaseInsensitive) < 0;
+        });
+        
+        std::sort(notContainedGroups.begin(), notContainedGroups.end(), [](const QString &a, const QString &b) {
+            return a.compare(b, Qt::CaseInsensitive) < 0;
+        });
+        
+        QStringList sortedGroups = containedGroups;
+        sortedGroups.append(notContainedGroups);
+        
+        m_groups[id] = sortedGroups;
     }
-
-    for (const auto id : m_groups.keys()) {
-        if (!m_model->getUser(id)) {
-            m_groups.remove(id);
+    
+    QStringList keysToRemove;
+    for (const auto &id : m_groups.keys()) {
+        if (!existingUserIds.contains(id)) {
+            keysToRemove.append(id);
         }
     }
+    
+    for (const auto &id : keysToRemove) {
+        m_groups.remove(id);
+    }
+}
+
+void AccountsController::updateSingleUserGroups(const QString &id)
+{
+    if (!m_model || !m_model->getUser(id))
+        return;
+        
+    updateGroups(id);
 }
 
 bool AccountsController::groupContains(const QString &id, const QString &name) const
@@ -401,6 +492,12 @@ bool AccountsController::groupEditAble(const QString &id, const QString &name) c
     return true;
 }
 
+bool AccountsController::groupExists(const QString &name) const
+{
+    QStringList existingGroups = allGroups();
+    return existingGroups.contains(name);
+}
+
 void AccountsController::createGroup(const QString &name)
 {
     m_worker->createGroup(name, 0, false);
@@ -436,6 +533,8 @@ void AccountsController::setGroup(const QString &id, const QString &group, bool
 
 void AccountsController::addUser(const QVariantMap &info)
 {
+    m_isCreatingUser = true;
+    
     const int type = info["type"].toInt();
     const QString name = info["name"].toString().simplified();
     const QString fullname = info["fullname"].toString().simplified();
@@ -725,6 +824,11 @@ void AccountsController::showDefender()
     m_worker->showDefender();
 }
 
+void AccountsController::playSystemSound(int soundType)
+{
+    m_worker->playSystemSound(soundType);
+}
+
 QString AccountsController::currentUserName() const
 {
     return m_model->getCurrentUserName();
