@@ -7,10 +7,12 @@
 
 #include "usermodel.h"
 #include "accountsworker.h"
+#include "creationresult.h"
 
 #include <QObject>
 #include <QSortFilterProxyModel>
 #include <QHash>
+#include <QtQml/qqml.h>
 
 namespace dccV25 {
 
@@ -48,6 +50,9 @@ public slots:
     bool autoLogin(const QString &id) const;
     void setAutoLogin(const QString &id, const bool enable);
     QString getOtherUserAutoLogin() const;
+    bool isQuickLoginVisible() const;
+    bool quickLogin(const QString &id) const;
+    void setQuickLogin(const QString &id, const bool enable);
     bool isNoPassWordLoginVisable() const;
     bool nopasswdLogin(const QString &id);
     void setNopasswdLogin(const QString &id, const bool enable);
@@ -62,6 +67,7 @@ public slots:
     bool groupContains(const QString &id, const QString &name) const;
     bool groupEnabled(const QString &id, const QString &name) const;
     bool groupEditAble(const QString &id, const QString &name) const;
+    bool groupExists(const QString &name) const;
     void createGroup(const QString &name);
     void deleteGroup(const QString &name);
     void modifyGroup(const QString &oldName, const QString &newName);
@@ -84,6 +90,9 @@ public slots:
     QString checkPassword(const QString &name, const QString &pwd);
     QVariantMap checkPasswordResult(int code, const QString &msg, const QString &name, const QString &pwd);
     void showDefender();
+    void playSystemSound(int soundType);
+
+    void updateSingleUserGroups(const QString &id);
 
 signals:
     void currentUserNameChanged();
@@ -94,6 +103,7 @@ signals:
     void userTypeChanged(const QString &userId, const int userType);
     void fullnameChanged(const QString &userId, const QString &fullname);
     void autoLoginChanged(const QString &userId, bool enable);
+    void quickLoginChanged(const QString &userId, bool enable);
     void nopasswdLoginChanged(const QString &userId, bool enable);
     void passwordAgeChanged(const QString &userId, const int age);
     void passwordModifyFinished(const QString &userId, const int exitCode, const QString &msg);
@@ -103,6 +113,7 @@ signals:
     void requestCreateGroup(const QString &userId);
     void requestClearEmptyGroup(const QString &userId);
     void showSafetyPage(const QString &errorTips);
+    void accountCreationFinished(CreationResult::ResultType resultType, const QString &message);
 protected:
     bool isSystemAdmin(const User *user) const;
     int adminCount() const;
@@ -115,6 +126,7 @@ private:
     QAbstractListModel    *m_accountsModel = nullptr;
     QHash<QString, QStringList> m_groups;
     QAbstractListModel    *m_groupsModel = nullptr;
+    bool m_isCreatingUser = false;
 };
 
 }
