@@ -9,6 +9,7 @@
 #include "securitydbusproxy.h"
 
 #include <ddbussender.h>
+#include <DDesktopServices>
 
 #include <QtConcurrent>
 #include <QFutureWatcher>
@@ -29,6 +30,7 @@ using namespace PolkitQt1;
 
 using namespace dccV25;
 DCORE_USE_NAMESPACE
+DGUI_USE_NAMESPACE
 
 AccountsWorker::AccountsWorker(UserModel *userList, QObject *parent)
     : QObject(parent)
@@ -398,9 +400,8 @@ void AccountsWorker::createAccount(const User *user)
     qDebug() << "create account";
 
     QFutureWatcher<CreationResult *> *watcher = new QFutureWatcher<CreationResult *>(this);
-    connect(watcher, &QFutureWatcher<CreationResult *>::finished, [this, watcher] {
+    connect(watcher, &QFutureWatcher<CreationResult *>::finished, [this, watcher, user] {
         CreationResult *result = watcher->result();
-        m_userModel->setAllGroups(m_accountsInter->GetGroups());
         Q_EMIT accountCreationFinished(result);
         Q_EMIT requestMainWindowEnabled(true);
         watcher->deleteLater();
@@ -482,6 +483,21 @@ void AccountsWorker::setAutoLogin(User *user, const bool autoLogin)
     });
 }
 
+void AccountsWorker::setQuickLogin(User *user, const bool quickLogin)
+{
+    UserDBusProxy *ui = m_userInters[user];
+    Q_ASSERT(ui);
+
+    QDBusPendingCall call = ui->SetQuickLogin(quickLogin);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [=] {
+        if (call.isError()) {
+            Q_EMIT user->quickLoginChanged(user->quickLogin());
+        }
+        watcher->deleteLater();
+    });
+}
+
 //切换账户权限
 void AccountsWorker::setAdministrator(User *user, const bool asAdministrator)
 {
@@ -590,6 +606,7 @@ void AccountsWorker::addUser(const QString &userPath)
     });
 
     connect(userInter, &UserDBusProxy::AutomaticLoginChanged, user, &User::setAutoLogin);
+    connect(userInter, &UserDBusProxy::QuickLoginChanged, user, &User::setQuickLogin);
     connect(userInter, &UserDBusProxy::IconListChanged, user, &User::setAvatars);
     connect(userInter, &UserDBusProxy::IconFileChanged, user, &User::setCurrentAvatar);
     connect(userInter, &UserDBusProxy::FullNameChanged, user, &User::setFullname);
@@ -619,6 +636,7 @@ void AccountsWorker::addUser(const QString &userPath)
     user->setName(userInter->userName());
     user->setFullname(userInter->fullName());
     user->setAutoLogin(userInter->automaticLogin());
+    user->setQuickLogin(userInter->quickLogin());
     user->setAvatars(userInter->iconList());
     user->setCurrentAvatar(userInter->iconFile());
     user->setNopasswdLogin(userInter->noPasswdLogin());
@@ -929,3 +947,8 @@ BindCheckResult AccountsWorker::checkLocalBind(const QString &uosid, const QStri
         result.error = m_syncInter->lastError();
     return result;
 }
+
+void AccountsWorker::playSystemSound(int soundType)
+{
+    DDesktopServices::playSystemSoundEffect(static_cast<DDesktopServices::SystemSoundEffect>(soundType));
+}
