@@ -16,6 +16,7 @@
 #include <QSettings>
 #include <QLoggingCategory>
 #include <QDir>
+#include <QFileInfo>
 #include <DDBusSender>
 
 #include <mutex>
@@ -104,8 +105,8 @@ static const QString getDevelopModeLicense(const QString &filePath, const QStrin
 static void notifyInfo(const QString &summary)
 {
     DUtil::DNotifySender(summary)
-            .appIcon("dde-control-center")
-            .appName(QObject::tr("dde-control-center"))
+            .appIcon("")
+            .appName("org.deepin.dde.control-center")
             .timeOut(5000)
             .call();
 }
@@ -113,8 +114,8 @@ static void notifyInfo(const QString &summary)
 static void notifyInfoWithBody(const QString &summary, const QString &body)
 {
     DUtil::DNotifySender(summary)
-            .appIcon("dde-control-center")
-            .appName(QObject::tr("dde-control-center"))
+            .appIcon("")
+            .appName("org.deepin.dde.control-center")
             .appBody(body)
             .timeOut(5000)
             .call();
@@ -172,13 +173,23 @@ CommonInfoWork::CommonInfoWork(CommonInfoModel *model, QObject *parent)
     connect(m_commonInfoProxy, &CommonInfoProxy::IsLoginChanged, m_commomModel, &CommonInfoModel::setIsLogin);
     connect(m_commonInfoProxy, &CommonInfoProxy::DeviceUnlockedChanged, m_commomModel, &CommonInfoModel::setDeveloperModeState);
     connect(m_commonInfoProxy, &CommonInfoProxy::DefaultEntryChanged, m_commomModel, &CommonInfoModel::setDefaultEntry);
-    connect(m_commonInfoProxy, &CommonInfoProxy::EnableThemeChanged, m_commomModel, &CommonInfoModel::setThemeEnabled);
+    // connect(m_commonInfoProxy, &CommonInfoProxy::EnableThemeChanged, m_commomModel, &CommonInfoModel::setThemeEnabled);
+    connect(m_commonInfoProxy, &CommonInfoProxy::EnableThemeChanged, m_commomModel, [this](bool ThemeEnable) {
+        m_commomModel->setGrubThemePath(m_commonInfoProxy->Background());
+        m_commomModel->setThemeEnabled(ThemeEnable);
+    });
     connect(m_commonInfoProxy, &CommonInfoProxy::TimeoutChanged, m_commomModel, [this] (const uint timeout) {
         m_commomModel->setBootDelay(timeout > 1);
     });
     connect(m_commonInfoProxy, &CommonInfoProxy::UpdatingChanged, m_commomModel, &CommonInfoModel::setUpdating);
     connect(m_commonInfoProxy, &CommonInfoProxy::BackgroundChanged, m_commomModel, [this] () {
-        QPixmap pix = QPixmap(m_commonInfoProxy->Background());
+        if (!m_commomModel->themeEnabled()) {
+            setEnableTheme(true);
+            m_commomModel->setThemeEnabled(true);
+        }
+        QString backgroundPath = m_commonInfoProxy->Background();
+        QPixmap pix = QPixmap(backgroundPath);
+        m_commomModel->setGrubThemePath(backgroundPath);
         m_commomModel->setBackground(pix);
     });
     connect(m_commonInfoProxy, &CommonInfoProxy::EnabledUsersChanged, m_commomModel, [this] (const QStringList &users) {
@@ -193,6 +204,8 @@ CommonInfoWork::CommonInfoWork(CommonInfoModel *model, QObject *parent)
     });
 
     connect(m_commonInfoProxy, &CommonInfoProxy::resetGrubEditAuthEnabled, this, &CommonInfoWork::resetEditAuthEnabled);
+
+    connect(m_commonInfoProxy, &CommonInfoProxy::DeveloperModeChanged, m_commomModel, &CommonInfoModel::setIsDeveloperMode);
 }
 
 CommonInfoWork::~CommonInfoWork()
@@ -210,6 +223,7 @@ void CommonInfoWork::active()
     m_commomModel->setShowGrubEditAuth(true);
     m_commomModel->setIsLogin(m_commonInfoProxy->IsLogin());
     m_commomModel->setDeveloperModeState(m_commonInfoProxy->DeviceUnlocked());
+    m_commomModel->setIsDeveloperMode(m_commonInfoProxy->DeveloperMode());
     m_commomModel->setThemeEnabled(m_commonInfoProxy->EnableTheme());
     m_commomModel->setBootDelay(m_commonInfoProxy->Timeout() > 1);
     m_commomModel->setGrubEditAuthEnabled(m_commonInfoProxy->EnabledUsers().contains(GRUB_EDIT_AUTH_ACCOUNT));
@@ -234,30 +248,29 @@ void CommonInfoWork::initGrubAnimationModel()
 {
     QList<QPair<int, QString>> scaleThemeList;
     if (IS_COMMUNITY_SYSTEM) {
-        scaleThemeList.append(QPair<int, QString>(2, "deepin-hidpi-ssd-logo"));
-        scaleThemeList.append(QPair<int, QString>(1, "deepin-ssd-logo"));
+        scaleThemeList.append(QPair<int, QString>(2, "boot_deepin"));
+        scaleThemeList.append(QPair<int, QString>(1, "boot_deepin"));
     } else {
-        scaleThemeList.append(QPair<int, QString>(2, "uos-hidpi-ssd-logo"));
-        scaleThemeList.append(QPair<int, QString>(1, "uos-ssd-logo"));
+        scaleThemeList.append(QPair<int, QString>(2, "boot_uos"));
+        scaleThemeList.append(QPair<int, QString>(1, "boot_uos"));
     }
 
     auto [factor, themeName] = getPlyMouthInformation();
     m_commomModel->setPlymouthScale(factor);
     m_commomModel->setPlymouthTheme(themeName);
 
-    static QString ThemePath = "/usr/share/plymouth/themes";
     QList<GrubAnimationData> list;
     for (auto item : scaleThemeList) {
         GrubAnimationData tempData;
         tempData.startAnimation = false;
-        tempData.imagePath = ThemePath + QDir::separator() + item.second + QDir::separator() + "logo.png";
+        tempData.imagePath = item.second;
         tempData.text = item.first == 2 ? tr("Large size") : tr("Small size");
         tempData.plymouthScale = item.first;
         tempData.checkStatus = factor == item.first;
         if (item.first == 2) {
-            tempData.scale = 0.5;
+            tempData.scale = 1;
         } else if (item.first == 1) {
-            tempData.scale = 0.3;
+            tempData.scale = 0.65;
         } else {
             tempData.scale = 1;
         }
@@ -331,10 +344,12 @@ void CommonInfoWork::setLogDebug(int index)
     argList << arg;
     QDBusPendingCall reply = m_debugConfigInter->asyncCall("SetDebug", QVariant::fromValue(argList));
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
-    connect(watcher, &QDBusPendingCallWatcher::finished, [watcher, reply] {
+    connect(watcher, &QDBusPendingCallWatcher::finished, [watcher, reply, this] {
         if (reply.isError()) {
                 qWarning() << "SetDebug failed:" << reply.error();
         }
+        // Todo 由于org.deepin.DebugConfig后端AllDebugLevel属性变化后没有发送信号，当前临时手动取数据，后端加上信号后改成监听信号
+        initDebugLogLevel();
         watcher->deleteLater();
     });
 }
@@ -485,7 +500,18 @@ void CommonInfoWork::setDefaultEntry(const QString &entry)
 
 void CommonInfoWork::setBackground(const QString &path)
 {
-    m_commonInfoProxy->setBackground(path);
+    QFileInfo fileInfo(path);
+    QString realPath = path;
+
+    if (fileInfo.exists() && fileInfo.isSymLink()) {
+        realPath = fileInfo.symLinkTarget();
+        if (QFileInfo(realPath).isRelative()) {
+            realPath = fileInfo.dir().absoluteFilePath(realPath);
+        }
+        qCDebug(DccCommonInfoWork) << "Resolved symlink" << path << "to" << realPath;
+    }
+
+    m_commonInfoProxy->setBackground(realPath);
 }
 
 void CommonInfoWork::setUeProgram(bool enabled)
