@@ -157,7 +157,7 @@ public:
 
     virtual QStringList shortTimeFormats() override
     {
-        return { "H:mm AP", "HH:mm AP", "H:mm", "HH:mm" };
+        return { "h:mm Ap", "hh:mm Ap", "H:mm", "HH:mm" };
     }
 
     virtual QStringList longTimeFormats() override
@@ -315,6 +315,7 @@ RegionAvailableData RegionProxy::allTextData(const QLocale &locale)
     allTextData += RegionProxy::defaultTextData(locale);
     allTextData += RegionProxy::customTextData(locale);
 
+    m_allFormat.clear();
     m_allFormat += m_defaultFormat;
     m_allFormat += m_customFormat;
 
