@@ -6,6 +6,8 @@
 #include "dccfactory.h"
 #include "layoutsmodel.h"
 
+#include <PolkitQt1/Authority>
+
 namespace dccV25 {
 DCC_FACTORY_CLASS(KeyboardController)
 
@@ -23,6 +25,7 @@ KeyboardController::KeyboardController(QObject *parent)
     connect(m_model, &KeyboardModel::capsLockChanged, this, &KeyboardController::capsLockChanged);
     connect(m_model, &KeyboardModel::userLayoutChanged, this, &KeyboardController::layoutCountChanged);
     connect(m_model, &KeyboardModel::curLayoutChanged, this, &KeyboardController::currentLayoutChanged);
+    connect(m_model, &KeyboardModel::keyboardEnabledChanged, this, &KeyboardController::keyboardEnabledChanged);
 
     connect(m_shortcutModel, &ShortcutModel::keyEvent, this, [this](bool press, const QString &shortcut){
         ShortcutInfo *current = m_shortcutModel->currentInfo();
@@ -94,6 +97,27 @@ void KeyboardController::setRepeatDelay(uint newRepeatDelay)
     m_worker->setRepeatDelay(newRepeatDelay);
 }
 
+bool KeyboardController::keyboardEnabled() const
+{
+    return m_model->keyboardEnabled();
+}
+
+void KeyboardController::setKeyboardEnabled(bool enabled)
+{
+    if (keyboardEnabled() == enabled)
+        return;
+
+    connect(PolkitQt1::Authority::instance(), &PolkitQt1::Authority::checkAuthorizationFinished, this, [this, enabled](PolkitQt1::Authority::Result authenticationResult) {
+        disconnect(PolkitQt1::Authority::instance(), nullptr, this, nullptr);
+        if (PolkitQt1::Authority::Result::Yes == authenticationResult) {
+            m_worker->setKeyboardEnabled(enabled);
+        } else {
+            Q_EMIT keyboardEnabledChanged();
+        }
+    });
+    PolkitQt1::Authority::instance()->checkAuthorization("org.deepin.dde.accounts.user-administration", PolkitQt1::UnixProcessSubject(getpid()), PolkitQt1::Authority::AllowUserInteraction);
+}
+
 bool KeyboardController::numLock() const
 {
     return m_model->numLock();
@@ -101,9 +125,6 @@ bool KeyboardController::numLock() const
 
 void KeyboardController::setNumLock(bool newNumLock)
 {
-    if (numLock() == newNumLock)
-        return;
-
     m_worker->setNumLock(newNumLock);
 }
 
@@ -179,6 +200,7 @@ QSortFilterProxyModel *KeyboardController::shortcutSearchModel()
     });
     connect(m_shortcutModel, &ShortcutModel::addCustomInfo, sourceModel, &ShortcutListModel::reset);
     connect(m_shortcutModel, &ShortcutModel::shortcutChanged, sourceModel, &ShortcutListModel::reset);
+    connect(m_shortcutModel, &ShortcutModel::windowSwitchChanged, sourceModel, &ShortcutListModel::reset);
 
     m_shortcutSearchModel->setSourceModel(sourceModel);
     m_shortcutSearchModel->setFilterRole(ShortcutListModel::SearchedTextRole);
@@ -187,15 +209,15 @@ QSortFilterProxyModel *KeyboardController::shortcutSearchModel()
     return m_shortcutSearchModel;
 }
 
-void KeyboardController::updateKey(const QString &id)
+void KeyboardController::updateKey(const QString &id, const int &type)
 {
     ShortcutInfo *shortcut = nullptr;
     if (!id.isEmpty()) { // new shortcuts
-        shortcut = m_shortcutModel->findInfoIf([id](ShortcutInfo *info){
-            return id == info->id;
+        shortcut = m_shortcutModel->findInfoIf([id, type](ShortcutInfo *info){
+            return id == info->id && type == info->type;
         });
         if (!shortcut) {
-            qWarning() << "shortcut not found..." << id;
+            qWarning() << "shortcut not found..." << id << type;
             return;
         }
     }
@@ -249,11 +271,11 @@ void KeyboardController::deleteCustomShortcut(const QString &id)
     m_worker->delShortcut(shortcut);
 }
 
-void KeyboardController::modifyShortcut(const QString &id, const QString &accels)
+void KeyboardController::modifyShortcut(const QString &id, const QString &accels, const int &type)
 {
-    ShortcutInfo *shortcut = m_shortcutModel->findInfoIf([id](ShortcutInfo *info){ return id == info->id; });
+    ShortcutInfo *shortcut = m_shortcutModel->findInfoIf([id, type](ShortcutInfo *info){ return id == info->id && type == info->type; });
     if (!shortcut) {
-        qWarning() << "shortcut not found..." << id;
+        qWarning() << "shortcut not found..." << id << type;
         return;
     }
 
