@@ -18,6 +18,7 @@
 #include <QDBusPendingCallWatcher>
 #include <QTranslator>
 
+using namespace DTK_NAMESPACE::Core;
 using namespace dccV25;
 bool caseInsensitiveLessThan(const MetaData &s1, const MetaData &s2);
 
@@ -34,6 +35,7 @@ KeyboardWorker::KeyboardWorker(KeyboardModel *model, QObject *parent)
     , m_model(model)
     , m_keyboardDBusProxy(new KeyboardDBusProxy(this))
     , m_translatorLanguage(nullptr)
+    , m_inputDevCfg(DConfig::create("org.deepin.dde.daemon", "org.deepin.dde.daemon.inputdevices", QString(), this))
 {
     connect(m_keyboardDBusProxy, &KeyboardDBusProxy::compositingEnabledChanged, this, &KeyboardWorker::onGetWindowWM);
     connect(m_keyboardDBusProxy, &KeyboardDBusProxy::Added, this, &KeyboardWorker::onAdded);
@@ -71,8 +73,7 @@ void KeyboardWorker::resetAll() {
 
 void KeyboardWorker::onGetWindowWM(bool value)
 {
-    if (m_shortcutModel)
-        m_shortcutModel->onWindowSwitchChanged(value);
+    windowSwitch();
 }
 
 void KeyboardWorker::setShortcutModel(ShortcutModel *model)
@@ -143,6 +144,16 @@ void KeyboardWorker::active()
     refreshLang();
     windowSwitch();
     refreshShortcut();
+    if (m_inputDevCfg->isValid()) {
+        QMetaObject::invokeMethod(m_model, "setKeyboardEnabled", Qt::DirectConnection, Q_ARG(bool, m_inputDevCfg->value("keyboardEnabled", true).toBool()));
+        connect(m_inputDevCfg, &DConfig::valueChanged, this, [=](QString key) {
+            if (key == "keyboardEnabled") {
+                QMetaObject::invokeMethod(m_model, "setKeyboardEnabled", Qt::DirectConnection, Q_ARG(bool, m_inputDevCfg->value(key).toBool()));
+            }
+        });
+    } else {
+        qWarning() << QString("DConfig is invalide, name:[%1], subpath[%2].").arg(m_inputDevCfg->name(), m_inputDevCfg->subpath());
+    }
 }
 
 void KeyboardWorker::deactive()
@@ -180,6 +191,8 @@ bool KeyboardWorker::keyOccupy(const QStringList &list)
 #ifndef DCC_DISABLE_KBLAYOUT
 void KeyboardWorker::onRefreshKBLayout()
 {
+    QDBusPendingCallWatcher *allLayoutResult = new QDBusPendingCallWatcher(m_keyboardDBusProxy->AllLayoutList(), this);
+    connect(allLayoutResult, &QDBusPendingCallWatcher::finished, this, &KeyboardWorker::onAllLayoutListsFinished);
     QDBusPendingCallWatcher *layoutResult = new QDBusPendingCallWatcher(m_keyboardDBusProxy->LayoutList(), this);
     connect(layoutResult, &QDBusPendingCallWatcher::finished, this, &KeyboardWorker::onLayoutListsFinished);
 
@@ -309,6 +322,13 @@ void KeyboardWorker::setCapsLock(bool value)
     m_keyboardDBusProxy->setCapslockToggle(value);
 }
 
+void KeyboardWorker::setKeyboardEnabled(bool value)
+{
+    if (m_inputDevCfg->isValid()) {
+        m_inputDevCfg->setValue("keyboardEnabled", value);
+    }
+}
+
 void KeyboardWorker::addUserLayout(const QString &value)
 {
     m_keyboardDBusProxy->AddUserLayout(m_model->kbLayout().key(value));
@@ -322,7 +342,7 @@ void KeyboardWorker::delUserLayout(const QString &value)
 bool caseInsensitiveLessThan(const MetaData &s1, const MetaData &s2)
 {
     QCollator qc;
-    int i = qc.compare(s1.text(), s2.text());
+    int i = qc.compare(s1.pinyin(), s2.pinyin());
     if (i < 0)
         return true;
     else
@@ -416,6 +436,16 @@ void KeyboardWorker::onLayoutListsFinished(QDBusPendingCallWatcher *watch)
     watch->deleteLater();
 }
 
+void KeyboardWorker::onAllLayoutListsFinished(QDBusPendingCallWatcher *watch)
+{
+    QDBusPendingReply<KeyboardLayoutList> reply = *watch;
+
+    KeyboardLayoutList tmp_map = reply.value();
+    m_model->setAllLayoutLists(tmp_map);
+
+    watch->deleteLater();
+}
+
 void KeyboardWorker::onLocalListsFinished(QDBusPendingCallWatcher *watch)
 {
     QDBusPendingReply<LocaleList> reply = *watch;
@@ -505,8 +535,9 @@ void KeyboardWorker::onPinyin()
     QDBusInterface dbus_pinyin("org.deepin.dde.Pinyin1", "/org/deepin/dde/Pinyin1",
                                "org.deepin.dde.Pinyin1");
 
-    const auto &layouts = m_model->kbLayout();
-    Q_FOREACH(const QString &key, layouts.keys()) {
+    const auto &currentLayouts = m_model->kbLayout();
+    const auto &layouts = m_model->allLayout().isEmpty() ? currentLayouts : m_model->allLayout();
+    Q_FOREACH (const QString &key, layouts.keys()) {
         MetaData md;
         QString title = layouts[key];
         md.setText(title);
@@ -515,11 +546,19 @@ void KeyboardWorker::onPinyin()
         QStringList letterFirstList;
         if (letterFirst.isLower() || letterFirst.isUpper()) {
             letterFirstList << QString(letterFirst);
-            md.setPinyin(title);
+            if (currentLayouts.contains(key)) {
+                md.setPinyin(" " + title);
+            } else {
+                md.setPinyin(title);
+            }
         } else {
             QDBusMessage message = dbus_pinyin.call("Query", title);
             letterFirstList = message.arguments()[0].toStringList();
-            md.setPinyin(letterFirstList.at(0));
+            if (currentLayouts.contains(key)) {
+                md.setPinyin(" " + letterFirstList.at(0));
+            } else {
+                md.setPinyin(letterFirstList.at(0));
+            }
         }
         append(md);
     }
