@@ -57,8 +57,7 @@ const QStringList &workspaceFilter = {"switch-to-workspace-left",
                                       "move-to-workspace-left",
                                       "move-to-workspace-right"};
 
-const QStringList &assistiveToolsFilter = {"ai-assistant",
-                                           "text-to-speech",
+const QStringList &assistiveToolsFilter = {"text-to-speech",
                                            "speech-to-text",
                                            "translation",
                                             "view-zoom-in",
@@ -199,10 +198,6 @@ void ShortcutModel::onParseInfo(const QString &info)
         systemFilterServer.removeOne("wm-switcher");
         systemFilterServer.removeOne("preview-workspace");
         systemShortKeys = systemFilterServer;
-    } else if (false == m_windowSwitchState) {
-        QStringList systemFilterServer = systemFilter;
-        systemFilterServer.removeOne("preview-workspace");
-        systemShortKeys = systemFilterServer;
     } else {
         systemShortKeys = systemFilter;
     }
@@ -211,6 +206,12 @@ void ShortcutModel::onParseInfo(const QString &info)
     systemFilterServer.removeOne("deepin-screen-recorder");
     systemShortKeys = systemFilterServer;
 #endif
+    // Save custom info IDs before clearing
+    QStringList customInfoIds;
+    for (auto info : m_customInfos) {
+        customInfoIds << info->id;
+    }
+
     qDeleteAll(m_infos);
 
     m_infos.clear();
@@ -229,9 +230,12 @@ void ShortcutModel::onParseInfo(const QString &info)
         ShortcutInfo *info = new ShortcutInfo();
         info->type         = type;
         info->accels       = obj["Accels"].toArray().first().toString();
-        info->name    = obj["Name"].toString();
-        info->pinyin =  toPinyin(info->name);
         info->id      = obj["Id"].toString();
+        info->name    = obj["Name"].toString();
+        if (systemShortKeys.contains(info->id)) {
+            info->name    = info->name.trimmed();
+        }
+        info->pinyin  =  toPinyin(info->name);
         info->command = obj["Exec"].toString();
 
         m_infos << info;
@@ -267,6 +271,18 @@ void ShortcutModel::onParseInfo(const QString &info)
     std::sort(m_systemInfos.begin(), m_systemInfos.end(), [ = ](ShortcutInfo *s1, ShortcutInfo *s2) {
         return systemShortKeys.indexOf(s1->id) < systemShortKeys.indexOf(s2->id);
     });
+    // More efficient implementation using std::find_if
+    auto it = std::find_if(m_systemInfos.begin(), m_systemInfos.end(),
+        [](const ShortcutInfo* info) { return info->id == "preview-workspace"; });
+    m_windowSwitchStateInfos.clear();
+    if (it != m_systemInfos.end()) {
+        int index = std::distance(m_systemInfos.begin(), it);
+        (*it)->index = index;
+        m_windowSwitchStateInfos << *it;
+        if (!m_windowSwitchState) {
+            m_systemInfos.erase(it);  // More efficient than removeOne
+        }
+    }
 
     std::sort(m_windowInfos.begin(), m_windowInfos.end(), [ = ](ShortcutInfo *s1, ShortcutInfo *s2) {
         return windowFilter.indexOf(s1->id) < windowFilter.indexOf(s2->id);
@@ -280,6 +296,23 @@ void ShortcutModel::onParseInfo(const QString &info)
         return assistiveToolsFilter.indexOf(s1->id) < assistiveToolsFilter.indexOf(s2->id);
     });
 
+    // Rebuild m_customInfos in original order first
+    QList<ShortcutInfo*> orderedCustomInfos;
+    for (const QString &id : customInfoIds) {
+        auto it = std::find_if(m_customInfos.begin(), m_customInfos.end(),
+            [id](ShortcutInfo *info) { return info->id == id && info->type == 1; });
+        if (it != m_customInfos.end()) {
+            orderedCustomInfos << *it;
+        }
+    }
+    // Add new custom infos that weren't in original list
+    for (auto info : m_customInfos) {
+        if (info->type == 1 && !customInfoIds.contains(info->id)) {
+            orderedCustomInfos << info;
+        }
+    }
+    m_customInfos = orderedCustomInfos;
+
     Q_EMIT listChanged(m_systemInfos, InfoType::System);
     Q_EMIT listChanged(m_windowInfos, InfoType::Window);
     Q_EMIT listChanged(m_workspaceInfos, InfoType::Workspace);
@@ -311,8 +344,9 @@ void ShortcutModel::onKeyBindingChanged(const QString &value)
 {
     const QJsonObject &obj       = QJsonDocument::fromJson(value.toStdString().c_str()).object();
     const QString     &update_id = obj["Id"].toString();
+    const int     &update_type = obj["Type"].toInt();
     auto res = std::find_if(m_infos.begin(), m_infos.end(), [ = ] (const ShortcutInfo *info)->bool{
-        return info->id == update_id;
+        return info->id == update_id && info->type == update_type;
     });
 
     if (res != m_infos.end()) {
@@ -329,6 +363,16 @@ void ShortcutModel::onWindowSwitchChanged(bool value)
 {
     if (m_windowSwitchState != value) {
         m_windowSwitchState = value;
+        if (m_windowSwitchState) {
+            for (int i = m_windowSwitchStateInfos.size() - 1; i >= 0; i--) {
+                m_systemInfos.insert(m_windowSwitchStateInfos.at(i)->index, m_windowSwitchStateInfos.at(i));
+            }
+        } else {
+            for (int i = 0; i < m_windowSwitchStateInfos.size(); i++) {
+                m_systemInfos.removeOne(m_windowSwitchStateInfos.at(i));
+            }
+        }
+        Q_EMIT windowSwitchChanged(m_windowSwitchState);
     }
 }
 
@@ -526,6 +570,8 @@ QVariant ShortcutListModel::data(const QModelIndex &index, int role) const
         return info->name + info->pinyin + "_" + displayKeys.join("_");
     case IdRole:
         return info->id;
+    case TypeRole:
+        return info->type;
     case KeySequenceRole:
         return displayKeys;
     case CommandRole:
@@ -550,6 +596,7 @@ QHash<int, QByteArray> ShortcutListModel::roleNames() const
     QHash<int, QByteArray> names = QAbstractListModel::roleNames();
     names[SearchedTextRole] = "searchedText";
     names[IdRole] = "id";
+    names[TypeRole] = "type";
     names[KeySequenceRole] = "keySequence";
     names[CommandRole] = "command";
     names[SectionNameRole] = "section";
