@@ -29,12 +29,11 @@ SoundWorker::SoundWorker(SoundModel *model, QObject *parent)
     , m_soundDBusInter(new SoundDBusProxy(this))
     , m_pingTimer(new QTimer(this))
     , m_inter(QDBusConnection::sessionBus().interface())
-    , m_sound(new QSoundEffect(this))
+    , m_sound(nullptr)
     , m_waitInputReceiptTimer(new QTimer(this))
     , m_waitOutputReceiptTimer(new QTimer(this))
     , m_mediaDevices(new QMediaDevices(this))
     , m_playAnimationTime(new QTimer(this))
-    , m_playAniIconIndex(1)
 {
     m_pingTimer->setInterval(5000);
     m_pingTimer->setSingleShot(false);
@@ -46,28 +45,14 @@ SoundWorker::SoundWorker(SoundModel *model, QObject *parent)
     m_waitInputReceiptTimer->setSingleShot(true);
     m_waitOutputReceiptTimer->setSingleShot(true);
 
-    m_sound->setAudioDevice(QMediaDevices::defaultAudioOutput());
-    qDebug() << " sound is playging " << m_sound->isPlaying();
+    updatePlayAniIconPath();
+
     initConnect();
 }
 
 void SoundWorker::initConnect()
 {
-
-    connect(m_mediaDevices, &QMediaDevices::audioOutputsChanged,this, [this] {
-        QAudioDevice defaultDevice = QMediaDevices::defaultAudioOutput();
-        qDebug() << "audioDeviceChanged Device:" << defaultDevice.description();
-        // 默认播放设备发生变化，需要重新构建新的对象
-        if (defaultDevice.description() != m_sound->audioDevice().description()) {
-            delete m_sound;
-            m_sound = new QSoundEffect(this);
-            m_sound->setAudioDevice(defaultDevice);
-        }
-    });
-
     connect(m_playAnimationTime, &QTimer::timeout, this, &SoundWorker::onAniTimerTimeOut);
-    connect(m_sound, &QSoundEffect::playingChanged, this, &SoundWorker::onSoundPlayingChanged);
-
     connect(m_model, &SoundModel::defaultSinkChanged, this, &SoundWorker::defaultSinkChanged);
     connect(m_model, &SoundModel::defaultSourceChanged, this, &SoundWorker::defaultSourceChanged);
     connect(m_model, &SoundModel::audioCardsChanged, this, &SoundWorker::cardsChanged);
@@ -99,6 +84,9 @@ void SoundWorker::initConnect()
     connect(m_waitOutputReceiptTimer, &QTimer::timeout, this, [this] {
         m_model->setOutPutPortComboEnable(true);
     });
+
+    connect(Dtk::Gui::DGuiApplicationHelper::instance(), &Dtk::Gui::DGuiApplicationHelper::themeTypeChanged,
+        this, &SoundWorker::updatePlayAniIconPath);
 }
 
 void SoundWorker::activate()
@@ -187,7 +175,7 @@ void SoundWorker::setActivePort(int index, int portType)
         m_waitInputReceiptTimer->start();
     }
 
-    Port* port = m_model->getPortForComboIndex(index, portType);
+    Port* port = m_model->getSoundDeviceData(index, portType);
     if (port) {
         setPort(port);
     }
@@ -272,27 +260,47 @@ void SoundWorker::enableAllSoundEffect(bool enable)
 
 void SoundWorker::setPortEnableIndex(int index, bool checked, int portType)
 {
-    SoundDeviceData* data = m_model->getSoundDeviceData(index, portType);
+    Port* data = m_model->getSoundDeviceData(index, portType);
     if (data) {
-        setPortEnabled(data->getCardId(), data->getPortId(), checked);
+        setPortEnabled(data->cardId(), data->id(), checked);
     }
 }
 
 void SoundWorker::playSoundEffect(int index)
 {
-    auto eff = m_model->soundEffectMap()[index].second;
-
-    if (m_sound->isPlaying()) {
-        m_sound->stop();
-        m_model->updatePlayAniIconPath(m_upateSoundEffectsIndex, "");
+    // Todo 当前QSoundEffect重复设置setSource的时候没有生效，当前先通过重新构造来控制
+    if (m_sound) {
+        if (m_sound->isPlaying()) {
+            m_model->updatePlayAniIconPath(m_upateSoundEffectsIndex, "");
+        }
+        delete m_sound;
+        m_sound = nullptr;
     }
+
+    m_sound = new QSoundEffect(this);
+    m_sound->setAudioDevice(QMediaDevices::defaultAudioOutput());
+    connect(m_sound, &QSoundEffect::playingChanged, this, &SoundWorker::onSoundPlayingChanged);
+
+    auto eff = m_model->soundEffectMap()[index].second;
     m_upateSoundEffectsIndex = index;
 
+    qDebug() << " sound play soundEffect :" << QUrl::fromLocalFile(m_model->soundEffectPathByType(eff));
     m_sound->setSource(QUrl::fromLocalFile(m_model->soundEffectPathByType(eff)));
     m_sound->setVolume(1);
     m_sound->play();
 }
 
+void SoundWorker::stopSoundEffectPlayback()
+{
+    if (m_sound) {
+        if (m_sound->isPlaying()) {
+            m_model->updatePlayAniIconPath(m_upateSoundEffectsIndex, "");
+        }
+        delete m_sound;
+        m_sound = nullptr;
+    }
+}
+
 void SoundWorker::setBluetoothMode(const QString &mode)
 {
     m_soundDBusInter->SetBluetoothAudioMode(mode);
@@ -381,13 +389,14 @@ void SoundWorker::cardsChanged(const QString &cards)
                 port->setEnabled(isEnabled);
                 port->setIsBluetoothPort(isBluetooth);
 
-                m_model->updateSoundDeviceModel(port);
-
                 const bool isActiveOuputPort = (portId == m_activeSinkPort) && (cardId == m_activeOutputCard);
                 const bool isActiveInputPort = (portId == m_activeSourcePort) && (cardId == m_activeInputCard);
 
                 port->setIsActive(isActiveInputPort || isActiveOuputPort);
 
+                if (port->isActive()) {
+                    m_model->setShowBluetoothMode(port->isBluetoothPort());
+                }
                 if (!include) { m_model->addPort(port); }
 
                 tmpPorts << portId;
@@ -407,6 +416,8 @@ void SoundWorker::cardsChanged(const QString &cards)
     }
 
     m_model->updatePortCombo();
+    m_model->updateAllDeviceModel();
+    m_model->updateActiveComboIndex();
 }
 
 void SoundWorker::activeSinkPortChanged(const AudioPort &activeSinkPort)
@@ -477,22 +488,14 @@ void SoundWorker::getSoundPathFinished(QDBusPendingCallWatcher *watcher)
 
 void SoundWorker::onAniTimerTimeOut()
 {
-    QString path = QString("qrc:/icons/deepin/builtin/icons/dcc_volume%1.svg").arg(m_playAniIconIndex);
-
-    m_model->updatePlayAniIconPath(m_upateSoundEffectsIndex, path);
-    m_playAniIconIndex++;
-    if (m_playAniIconIndex > 3) {
-        m_playAniIconIndex = 1;
-    }
+    m_model->updatePlayAniIconPath(m_upateSoundEffectsIndex, m_playAniIconPath);
 }
 
 void SoundWorker::onSoundPlayingChanged()
 {
-    m_playAniIconIndex = 1;
     QString path("");
-    if (m_sound->isPlaying()) {
-        path = QString("qrc:/icons/deepin/builtin/icons/sound_preview_%1.svg").arg(m_playAniIconIndex);
-        m_playAniIconIndex++;
+    if (m_sound && m_sound->isPlaying()) {
+        path = m_playAniIconPath;
         m_playAnimationTime->start();
     } else {
         m_playAnimationTime->stop();
@@ -508,14 +511,13 @@ void SoundWorker::updatePortActivity()
         const bool isActiveInputPort = (port->id() == m_activeSourcePort) && (port->cardId() == m_activeInputCard);
         port->setIsActive(isActiveInputPort || isActiveOuputPort);
 
-        if (isActiveOuputPort) {
-            m_model->setActiveOutPutPort(port);
-        }
+        m_model->updateSoundDeviceModel(port);
 
-        if (isActiveInputPort) {
-            m_model->setActiveinPutPort(port);
+        if (isActiveOuputPort) {
+            m_model->setShowBluetoothMode(port->isBluetoothPort());
         }
     }
+    m_model->updateActiveComboIndex();
 }
 
 void SoundWorker::initAudioServerData()
@@ -543,6 +545,13 @@ void SoundWorker::initAudioServerData()
     }
 }
 
+void SoundWorker::updatePlayAniIconPath()
+{
+    auto themeType = Dtk::Gui::DGuiApplicationHelper::instance()->themeType();
+    auto themeTypeStr = themeType == Dtk::Gui::DGuiApplicationHelper::ColorType::DarkType ? "dark" : "light";
+    m_playAniIconPath = QString("qrc:/icons/deepin/builtin/icons/%1/volume_sound_wave_ani.webp").arg(themeTypeStr);
+}
+
 void SoundWorker::setAudioServerIndex(int index)
 {
     if (index >= 0  && AudioServerNames.count() > index) {
