@@ -21,8 +21,10 @@
 #include <qregularexpression.h>
 #include <qtimezone.h>
 #include <signal.h>
+#include <DDesktopServices>
 
 DCORE_USE_NAMESPACE
+DGUI_USE_NAMESPACE
 
 const QString USER_EXPERIENCE_SERVICE = "com.deepin.userexperience.Daemon";
 
@@ -221,6 +223,11 @@ void SystemInfoWork::copyTextToClipboard(const QString &text)
     }
 }
 
+void SystemInfoWork::playSystemSound(int soundType)
+{
+    DDesktopServices::playSystemSoundEffect(static_cast<DDesktopServices::SystemSoundEffect>(soundType));
+}
+
 void SystemInfoWork::initSystemCopyright()
 {
     const QSettings settings("/etc/deepin-installer.conf", QSettings::IniFormat);
@@ -469,6 +476,11 @@ void SystemInfoWork::setUeProgramEnabled(bool enabled)
 
 void SystemInfoWork::onLicenseAuthorizationProperty()
 {
+    if (DSysInfo::isDeepin()) {
+        ActiveState newLicenseState = static_cast<ActiveState>(m_systemInfDBusProxy->authorizationState());
+        m_model->setLicenseState(newLicenseState);
+    }
+
     // 从授权服务器获取授权类型
     QString authorizationProperty = getLicenseAuthorizationPropertyString();
     QString version = "";
